@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.3.0
+#www2sms.py v1.3.1
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@ from PyQt4.QtGui import QMainWindow, QDialog, QPushButton, QMessageBox, QPixmap
 from www2sms_gui_main import Ui_MainWindow
 from www2sms_gui_widget_account import Ui_FormAccount
 from www2sms_gui_dialog_progress import Ui_Form_Progress
-__version__ = '1.3.0'
+__version__ = '1.3.1'
 __version_info__ = tuple([ int(num) for num in __version__.split('.')])
 
 USER = pwd.getpwuid(os.getuid())[0]
@@ -149,7 +149,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			    if e.errno == errno.EEXIST:
 				pass
 			    else:
-				raise Exception("Failed to create %s. (%s, %s)" %(GPG_DIR, errno, strerror))
+				raise Exception("Failed to create %s. (%s, %s)" %(GPG_DIR, e.errno, strerror))
 			URL = "http://olausson.de/downloads/finish/2/2"
 			try:
 				dl = uo(URL)
@@ -168,11 +168,16 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			stdo, stde = ps.communicate()
 			if not re.search(MyID, stdo):
 				# import my pubkey:
-				cmd = ["gpg", "--no-permission-warning", "--preserve-permissions", "--lock-never", "--homedir", GPG_DIR, "--keyserver", "pgpkeys.pca.dfn.de", "--recv-key", MyID]
-				ps = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-				stdo, stde = ps.communicate()
-				if ps.returncode != 0:
-					QMessageBox.warning(self, 'www2sms', 'Failed to import GPG signature')
+				GPG_SERVERS = ["keys.gnupg.net", "pgp.dtype.org", "search.keyserver.net", "subkeys.pgp.net", "wwwkeys.pgp.net", "wwwkeys.us.pgp.net"]
+				for GPG_SERVER in GPG_SERVERS:
+					cmd = ["gpg", "--no-permission-warning", "--preserve-permissions", "--lock-never", "--homedir", GPG_DIR, "--keyserver", GPG_SERVER, "--recv-key", MyID]
+					ps = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+					stdo, stde = ps.communicate()
+					returncode = ps.returncode
+					if returncode == 0:
+						break
+				if returncode != 0:
+					QMessageBox.warning(self, 'www2sms', 'Failed to import GPG signature. GPG servers not responding')
 					return
 			# verify and decrypt www2sms_providers.py.tar.gpg
 			cmd = ["gpg", "--no-permission-warning", "--preserve-permissions", "--lock-never", "--homedir", GPG_DIR, "-q", "--yes", CONFIG_DIR+"/www2sms_providers.py.tar.gpg"]
@@ -208,7 +213,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 		    	self.ui.pushButton_Send.setEnabled(False)
 		## Enable the "advanced" options if supported
 		if (provider_index >= 0) and providers[provider_index].hasAdvancedFeatures():
-			adv_module_name = "www2sms_gui_widget_advanced_%s" %( providers[provider_index].AdvModName() )	
+			adv_module_name = "www2sms_gui_widget_advanced_%s" %( providers[provider_index].AdvModName() )
 			AdvSetForm = __import__(adv_module_name)
 			class FormAdv(QDialog, AdvSetForm.Ui_FormAdvanced):
 				def __init__(self, win_parent = None):
@@ -394,7 +399,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			self.enableTabs(-1)
 		else:
 			self.AccSet.on_SetupAlias_activated()
-		
+
 		QMessageBox.information(self.AccSet, 'www2sms', "Account %s deleted" %(ALIAS))
 
 	# Method which is called, when an account is created/updated
@@ -527,7 +532,7 @@ def mk_db():
 	if e.errno == errno.EEXIST:
 	    pass
 	else:
-	    raise Exception("Failed to create %s. (%s, %s)" %(CONFIG_DIR, errno, strerror))
+	    raise Exception("Failed to create %s. (%s, %s)" %(CONFIG_DIR, e.errno, strerror))
 	# Change to the config dir.
 	os.chdir(CONFIG_DIR)
 	conn = sqlite3.connect('www2sms.db')
