@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-__version__ = '1.0.0'
+__version__ = '1.2.1'
 __version_info__ = tuple([ int(num) for num in __version__.split('.')])
 
 import sys, re, mechanize, base64, urllib2, time, calendar, urllib, sqlite3
@@ -8,7 +8,7 @@ from lxml.html import soupparser
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtGui import QApplication, QDialog, QImage, QPixmap
 from www2sms_gui_dialog_captcha import Ui_DialogCaptcha
-
+import time
 
 
 class ShowCAPTCHA(QDialog, Ui_DialogCaptcha):
@@ -240,7 +240,8 @@ class provider_o2online_de(provider):
 			return SCHEDULE, SENDER, FLASH
 
 	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
-		LOGINURL = 'https://o2online.de'
+		#LOGINURL = 'https://email.o2online.de'
+		LOGINURL = 'http://www.o2online.de/asp/login/comcenter-login?scheme=http&port=80&server=email.o2online.de&url=%2Fssomanager.osp%3FAPIID%3DAUTH-WEBSSO'
 		execute = True
 		if execute:
 			# Get the values for the advanced settings.
@@ -307,11 +308,11 @@ class provider_o2online_de(provider):
 			#------------------------------------
 			UpdatePbar(self, MainWindow, app, "3", "Step 3: Log in to MyO2")
 			try:
-				br.select_form(name='loginForm')
+				br.select_form(nr=0)
 			except Exception, e:
 				return error(self, MainWindow, e, "Step 3: Faild to select the login Form")
-			br.form['loginName'] = LOGIN
-			br.form['password'] = PASSWORD
+			br.form['loginName:loginName'] = LOGIN
+			br.form['password:password'] = PASSWORD
 			#br.find_control(name="url").value = ["1"]
 			#br.form.find_control(name="url", kind="select").value = ["1]
 			#br.form['url'] = ["https://email.o2online.de/ssomanager.osp?APIID=AUTH-WEBSSO&#38;et_cid=22&#38;et_lid=64"]
@@ -322,7 +323,6 @@ class provider_o2online_de(provider):
 				return error(self, MainWindow, e, 'Step 3: Failed to load "Mein O2"')
 			if re_fail.search(str(response)):
 				return error(self, MainWindow, False, 'Step 3: Probably wrong login parameters, check your account setup')
-
 			#------------------------------------
 			# Open the EMAIL-Center
 			#------------------------------------
@@ -332,21 +332,11 @@ class provider_o2online_de(provider):
 			#------------------------------------
 			if re.search("weitergeleitet", response):
 				try:
-					br.select_form(nr = 0)
-					br.submit(nr=0)
+					form = br.select_form(nr=0)
+					#br.submit(nr=0)
+					br.submit(name='_eventId_login', label='Weiter')
 				except Exception, e:
-					return error(self, MainWindow, e, 'Step 5: Redirection failed, please try again')
-
-			try:
-				br.find_link(text_regex="Mail")
-			except mechanize.LinkNotFoundError, e:
-				return error(self, MainWindow, e, 'Step 5: Link "E-Mail" not found, please try again')
-			req = br.click_link(text_regex="Mail")
-			try:
-				br.open(req)
-				response = br.response().read()
-			except Exception, e:
-				return error(self, MainWindow, e, 'Step 5: Failed to open the EmailCenter')
+					return error(self, MainWindow, e, 'Step 5: Automatic redirection failed, please try again')
 
 			#------------------------------------
 			# Open the SMS-Center
@@ -1135,7 +1125,7 @@ class provider_arcor_de(provider):
 		try:
 			br.select_form(name='loginpromoform')
 			br.submit(name='weiter', label='Weiter')
-		except mechanize._mechanize.FormNotFoundError:
+		except mechanize.FormNotFoundError:
 			pass
 
 		UpdatePbar(self, MainWindow, app, "6", "Sending SMS")
@@ -1155,7 +1145,101 @@ class provider_arcor_de(provider):
 			return True, "SMS was sent."
 		else:
 			return False, 'Message not sent'
-		time.sleep(5)
+		MainWindow.Stat.close()
+
+# 160by2 1.1
+# http://m.160by2.com
+# 160by2 Provider written by Bjoern Olausson (maemo@olausson.de)
+# 160by2 Provider modded by Ejas Mudar (ejasmudar@gmail.com)
+class provider_160by2(provider):
+	def getName(self):
+		return '160by2 (India)'
+	def hasAdvancedFeatures(self):
+		return False
+	def chars_per_sms(self):
+		return 140, 140
+	def num_regexp(self, num):
+		# Remove everything except numbers. Spaces, hyphens and + removed
+		num = re.sub(r'[^(0-9)]', '', num)
+		
+		# Remove single or double zeroes in the begining
+		num = re.sub(r'^(0)', '', num)
+		num = re.sub(r'^(0)', '', num)
+		
+		# Ensures only numbers starting with 9 (mobile numbers).
+		# Also true for Kuwait, Saudi, etc whose codes begin with 9
+		# Further internationalisations to be done.
+		if re.match('^[69]', num):
+			if re.match('^[7-9]', num) and len (num) == 10:
+				return True, num, 'Valid Indian Mobile Number'
+			else:
+				return True, num, 'Valid Non-Indian Mobile Number'
+		else:
+		    return False, num, 'Invalid Mobile Number'
+
+	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
+		MainWindow.Stat.show()
+		MainWindow.Stat.ui.progressBar.setMinimum(0)
+		MainWindow.Stat.ui.progressBar.setMaximum(7)
+
+		iURL = "http://m.160by2.com"
+		URL ="http://m.160by2.com/index.asp?in=yes"
+		# set up our browser
+		UpdatePbar(self, MainWindow, app, "1", "Initiating the browser")
+		br = mechanize.Browser()
+
+		# login
+		UpdatePbar(self, MainWindow, app, "2", "Connecting to login page")
+		try:
+			br.open(URL)
+		except mechanize.HTTPError, e:
+			try:
+				br.open(iURL)
+			except Exception, e:
+				return error(self, MainWindow, e, "Step 2: Failed to open\n%s" %(iURL))
+		except Exception, e:
+			return error(self, MainWindow, e, "Step 2: Failed to open\n%s" %(URL))
+
+		UpdatePbar(self, MainWindow, app, "3", "Logging in")
+		br.select_form(name='frm')
+		br.form['txtUserName'] = LOGIN
+		br.form['txtPasswd'] = PASSWORD
+		try:
+			br.submit()
+		except Exception, e:
+			return error(self, MainWindow, e, "Step 3: Failed to submit login credentials")
+
+		# verify our login worked and return error if not
+		UpdatePbar(self, MainWindow, app, "4", "Checking login")
+		try:
+			br.find_link(text_regex="Logoff")
+		except Exception, e:
+			return error(self, MainWindow, e, "Step 4: Login failed, probably wrong login/password")
+
+		UpdatePbar(self, MainWindow, app, "5", "Open \"Compose (Send SMS)\"")
+		try:
+			req = br.click_link(text_regex="Compose \(Send SMS\)")
+			br.open(req)
+			response = br.response().read()
+		except Exception, e:
+			return error(self, MainWindow, e, "Step 5: Failed to open \"Compose (Send SMS)\"")
+
+		UpdatePbar(self, MainWindow, app, "6", "Sending SMS")
+		try:
+			br.select_form(name='frm')
+			br.form['txt_mobileno'] = NUMBER
+			br.form['txt_msg'] = SMSTEXT.encode(br.encoding())
+			br.submit(name='cmdSend', label='Send SMS')
+		except Exception, e:
+			return error(self, MainWindow, e, "Step 6: Error submitting SMS form")
+
+		# check to see if our send worked
+		UpdatePbar(self, MainWindow, app, "7", "Confirming SMS sent")
+		response = br.response().read()
+		if re.search(r'SMS Sent Successfully', response):
+			return True, "SMS Sent Successfully"
+		else:
+			return False, 'Message not sent'
 		MainWindow.Stat.close()
 
 # vodafone.it 0.8 alpha
@@ -1251,3 +1335,124 @@ class provider_arcor_de(provider):
 			#return False, 'Message not sent'
         	#MainWindow.Stat.close()
 
+
+# Tele2 Norway 1.0
+# http://tele2.no
+# Tele2 Norway Provider written by Håvard Myklebust (hmyklebust@gmail.com)
+class provider_tele2_no(provider):
+	def getName(self):
+		return 'Tele2 (Norway)'
+	def hasAdvancedFeatures(self):
+		return False
+	def chars_per_sms(self):
+		return 160, 720
+	def num_regexp(self, num):
+	    	# Get rid of everything except
+		num = re.sub(r'[^(0-9)|\+]', '', num)
+		# handle a couple of number formats (only mobile numbers allowed)
+		if re.search(r'^\+47\d{8}$', num):	# ITU format, +47 is the Norway
+			num = num[3:]
+			return True, num, 'Valid Number'
+		elif re.search(r'^\d{8}$', num):	# local dialing format
+			num = num[:]
+			return True, num, 'Valid Number'
+		else:
+			return False, num, 'Only Norwegion mobile phone numbers allowed'
+
+	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
+                # XXX: GUI manipulation
+                MainWindow.Stat.show()
+		MainWindow.Stat.ui.progressBar.setMinimum(0)
+		MainWindow.Stat.ui.progressBar.setMaximum(8)
+
+		# set up our browser
+		UpdatePbar(self, MainWindow, app, "1", "Initiating the browser")
+		br = mechanize.Browser()
+		br.addheaders = [('User-Agent','Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.2.3) \Gecko/20100423 Ubuntu/10.04 (lucid) Firefox/3.6.3')]
+		cj = cookielib.LWPCookieJar()
+		br.set_cookiejar(cj)
+
+		# login to provider page
+		try:
+			UpdatePbar(self, MainWindow, app, "2", "Connecting to login page")
+			br.open('https://www.tele2.no/ajaxMyPages_LoginMobile.html')
+			UpdatePbar(self, MainWindow, app, "3", "Logging in")
+			br.select_form(nr=0)
+			br.form['user'] = LOGIN
+			br.form['pass'] = PASSWORD
+			br.submit()
+		except	Exception, msg:
+			print Exception, msg
+			return False, "Error logging in"
+
+		# verify login
+	   	UpdatePbar(self, MainWindow, app, "4", "Checking login")
+		response = br.response().read()
+		if not re.search(r'ajax-success', response):
+			return False, 'Error logging in'
+
+		# open "send SMS" site
+   	        UpdatePbar(self, MainWindow, app, "5", "Opening SMS page")
+		br.open('https://www.tele2.no/minesider/send-sms.html')
+		response = br.response().read()
+
+		# search site for actual address for sending SMS messages and navigat to it
+		address = 'https://tele2minside.linkmobility.com/SmsSender/SendSms.aspx'
+		line = response[response.find(address):]
+		double_quote_index = line.find("\"")
+		single_quote_index = line.find("\'")
+		end = double_quote_index if single_quote_index == -1 or double_quote_index < single_quote_index else single_quote_index
+		sms_address = line[:end]
+		try:
+			br.open(sms_address)
+		except:
+			return False, 'Error opening free SMS web page'
+
+		# Find number of free SMS messages left
+		response = br.response().read()
+
+   	        UpdatePbar(self, MainWindow, app, "6", "Checking maximum SMS messages per day")
+		index = response.find("GratisLimit")
+		line = response[index:]
+		sms_per_day = line[line.find(">")+1:line.find("<")]
+
+		response = br.response().read()
+		index = response.find("AntallGratis")
+		line = response[index:]
+		sms_sent = line[line.find(">")+1:line.find("<")]
+
+		try:
+			sms_left = "%i" % (int(sms_per_day) - int(sms_sent))
+			if sms_left == 0:
+				return False, "Sorry, no more free messages today"
+		except ValueError:
+			sms_left = "Unknown"
+
+		# send SMS
+	        UpdatePbar(self, MainWindow, app, "7", "Sending SMS message")
+		try:
+			br.select_form(nr=0)
+			br.form['smsrecivers$mottakere'] = NUMBER
+			br.form['MessageSMS'] = SMSTEXT
+
+			ctrl_eventtarget = br.find_control(type="hidden", name="__EVENTTARGET")
+			ctrl_eventtarget.readonly= False
+			ctrl_eventtarget.value= "Send"
+
+			ctrl_eventargument = br.find_control(type="hidden", name="__EVENTARGUMENT")
+			ctrl_eventargument.readonly= False
+			ctrl_eventargument.value= ""
+
+			br.submit()
+		except Exception, msg:
+			print response
+			print Exception, msg
+			return False, 'Error submitting SMS form'
+
+		# verify that sending worked
+   	        UpdatePbar(self, MainWindow, app, "8", "Confirming SMS sent")
+		response = br.response().read()
+		# TODO: check this response (to verify that sending worked)
+
+		return True, "Message sent. %s messages left." % sms_left
+        	MainWindow.Stat.close()
\ No newline at end of file
